#PYME uses date based versions (yy.m.d)
version = '20.09.18'

#Git changeset id
changeset = '8333bc3b9bcf'
